@@ -156,7 +156,7 @@ struct PathGrammar : public qi::grammar<Iterator, IWORKPath::Impl(), ascii::spac
     , line()
     , cCurve()
     , qCurve()
-    , close()
+    , close('Z')
   {
     using qi::attr;
     using qi::as;
@@ -172,8 +172,6 @@ struct PathGrammar : public qi::grammar<Iterator, IWORKPath::Impl(), ascii::spac
 
     cCurve %= 'C' >> double_ >> double_ >> double_ >> double_ >> double_ >> double_;
 
-    close = 'Z';
-
     curve %= as<Curve_t>()[move >> +(line | cCurve | qCurve) >> -close];
     path %= as<Path_t>()[+curve >> *(omit[move]) ];
 
@@ -677,9 +675,9 @@ void IWORKPath::operator*=(const glm::dmat3 &tr)
 void IWORKPath::computeBoundingBox(double &minX, double &minY, double &maxX, double &maxY, double factor) const
 {
   ComputeBoundingBox bdCompute;
-  for (auto &it : m_impl->m_path)
+  for (auto const &it : m_impl->m_path)
   {
-    for (auto &cIt : it)
+    for (auto const &cIt : it)
       apply_visitor(bdCompute, cIt);
   }
   minX=factor*bdCompute.m_boundX[0];
