@@ -61,7 +61,7 @@ void IWORKTabularInfoElement::startOfElement()
 {
   getState().m_tableData = std::make_shared<IWORKTableData>();
   assert(!getState().m_currentTable);
-  getState().m_currentTable = getCollector().createTable(getState().m_tableNameMap, getState().m_langManager);
+  getState().m_currentTable = getCollector().createTable(getState().m_tableNameMap, getState().m_formatNameMap, getState().m_langManager);
   if (isCollector())
     getCollector().startLevel();
 }
